summaryrefslogtreecommitdiffstats
path: root/custom/mkcustom.py
diff options
context:
space:
mode:
Diffstat (limited to 'custom/mkcustom.py')
-rw-r--r--custom/mkcustom.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/custom/mkcustom.py b/custom/mkcustom.py
index 0e8deab..94f7021 100644
--- a/custom/mkcustom.py
+++ b/custom/mkcustom.py
@@ -1,4 +1,4 @@
"""This Python script uses the SIP build system to create a Makefile for
building a custom Python interpreter. The script doesn't take any command line
flags - just edit it to suit your needs. You will also need to edit custom.c
or customw.c.
@@ -6,11 +6,11 @@ or customw.c.
import sys
-import sipconfig
+import sip_tqt_config
-# Get the SIP configuration.
-cfg = sipconfig.Configuration()
+# Get the SIP-TQt configuration.
+cfg = sip_tqt_config.Configuration()
# This is the name of the interpreter executable (excluding any platform
@@ -50,7 +50,7 @@ if sys.platform == "linux2":
# Create a dictionary describing the target and source files to be passed to
# the SIP build system.
build = {}
if sys.platform == "win32" and WindowsInterpreter:
@@ -66,7 +66,7 @@ else:
qt = (cfg.qt_version > 0)
# Create the Makefile instance.
-mf = sipconfig.ProgramMakefile(cfg, build, python=True, console=console, qt=qt)
+mf = sip_tqt_config.ProgramMakefile(cfg, build, python=True, console=console, qt=qt)
# Modify the Makefile according to the values set above.
mf.extra_lib_dirs.extend(ExtraLibraryDirectories)
@@ -1,4 +1,4 @@
-"""This Python script uses the SIP build system to create a Makefile for
+"""This Python script uses the SIP-TQt build system to create a Makefile for
building a custom Python interpreter. The script doesn't take any command line
flags - just edit it to suit your needs. You will also need to edit custom.c
@@ -50,7 +50,7 @@ if sys.platform == "linux2":
# Create a dictionary describing the target and source files to be passed to
-# the SIP build system.
+# the SIP-TQt build system.
build = {}
if sys.platform == "win32" and WindowsInterpreter: